Index: src/x64/macro-assembler-x64.cc |
diff --git a/src/x64/macro-assembler-x64.cc b/src/x64/macro-assembler-x64.cc |
index 1d375e15f8a3e295ca346104838dd9f0873ba2da..7c8a3667e3756f7b3789068f7b7e7e8d7c183026 100644 |
--- a/src/x64/macro-assembler-x64.cc |
+++ b/src/x64/macro-assembler-x64.cc |
@@ -3628,14 +3628,17 @@ void MacroAssembler::LoadContext(Register dst, int context_chain_length) { |
movq(dst, rsi); |
} |
// We should not have found a 'with' context by walking the context chain |
// (i.e., the static scope chain and runtime context chain do not agree). |
// A variable occurring in such a scope should have slot type LOOKUP and |
// not CONTEXT. |
if (emit_debug_code()) { |
- cmpq(dst, Operand(dst, Context::SlotOffset(Context::FCONTEXT_INDEX))); |
- Check(equal, "Yo dawg, I heard you liked function contexts " |
- "so I put function contexts in all your contexts"); |
+ CompareRoot(FieldOperand(dst, HeapObject::kMapOffset), |
+ Heap::kWithContextMapRootIndex); |
+ Check(not_equal, "Variable resolved to with context."); |
+ CompareRoot(FieldOperand(dst, HeapObject::kMapOffset), |
+ Heap::kCatchContextMapRootIndex); |
+ Check(not_equal, "Variable resolved to catch context."); |
} |
} |
@@ -3628,14 +3628,17 @@ void MacroAssembler::LoadContext(Register dst, int context_chain_length) { |
movq(dst, rsi); |
} |
- // We should not have found a 'with' context by walking the context chain |
- // (i.e., the static scope chain and runtime context chain do not agree). |
- // A variable occurring in such a scope should have slot type LOOKUP and |
- // not CONTEXT. |
+ // We should not have found a with or catch context by walking the context |
+ // chain (i.e., the static scope chain and runtime context chain do not |
+ // agree). A variable occurring in such a scope should have slot type |
+ // LOOKUP and not CONTEXT. |
if (emit_debug_code()) { |